@@ -29,12 +29,10 @@ def _format_args(args_info, include_annotations=True, ignore_self=None):
 class PythonPythonMapper(PythonMapperBase):
     """A base class for all types of representations of Python objects.
 
-    :var name: The name given to this object.
-    :vartype name: str
-    :var id: A unique identifier for this object.
-    :vartype id: str
-    :var children: The members of this object.
-    :vartype children: list(PythonPythonMapper)
+    Attributes:
+        name (str): The name given to this object.
+        id (str): A unique identifier for this object.
+        children (list(PythonPythonMapper)): The members of this object.
     """
 
     language = "python"
@@ -203,7 +201,9 @@ class PythonFunction(PythonPythonMapper):
             (_format_args(args), return_annotation)
             for args, return_annotation in obj["overloads"]
         ]
-        """The list of overloaded signatures ``[(args, return_annotation), ...]`` of this function.
+        """The overloaded signatures of this function.
+
+        Each tuple is a tuple of ``(args, return_annotation)``
 
         :type: list(tuple(str, str))
         """
