@@ -152,7 +152,7 @@ class Parser:
     def parse_asyncfunctiondef(self, node):
         return self.parse_functiondef(node)
 
-    def parse_functiondef(self, node):  # pylint: disable=too-many-branches
+    def parse_functiondef(self, node):
         if astroid_utils.is_decorated_with_property_setter(node):
             return []
 
@@ -237,7 +237,7 @@ class Parser:
             "type": type_,
             "name": node.name,
             "full_name": node.name,
-            "doc": _prepare_docstring(node.doc or ""),
+            "doc": _prepare_docstring(node.doc_node.value if node.doc_node else ""),
             "children": [],
             "file_path": path,
             "encoding": node.file_encoding,
